<template>
  <div>
    <el-dialog custom-class="bbsl-location-dialog" top="8vh" :close-on-click-modal="false" :title="title"
               v-if="visible" :visible="visible" width="1200px" :before-close="handleClose">

      <template slot="title">
				<span class="collapse-title">
					<i class="collapse-title-icon el-icon-info"></i>
					基础信息
				</span>
      </template>
      <div class="bbsl-scroll-pane">
        <el-form class="bbsl-scroll-form" ref="formInfo" :rules="rules" :model="params" label-width="100px">
          <el-row>
            <el-col :span="12">
              <el-form-item label="考核标题：" prop=" assessTitle">
                <el-input clearable placeholder="请输入考核标题" maxlength="1000" v-model="params.assessTitle">
                </el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="考核方式：" prop="assessType">
                <el-select clearable style="width: 100%" placeholder="请选择考核方式"
                           v-model="params.assessType">
                  <el-option v-for="item in assessTypeList" :key="item.value" :label="item.name"
                             :value="item.value"></el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="12">
              <el-form-item label="考核年度：" prop="assessYear">
                <el-date-picker v-model="params.assessYear" type="year" value-format="yyyy"
                                placeholder="请选择考核年度">
                </el-date-picker>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="发布状态：" prop="publishStatus">
                <el-select clearable style="width: 100%" placeholder="请选择发布状态"
                           v-model="params.publishStatus">
                  <el-option v-for="item in fbztList" :key="item.value" :label="item.name"
                             :value="item.value"></el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-form-item label="备注：" prop="memo">
            <el-input type="textarea" :autosize="{minRows: 3, maxRows: 4}" maxlength="500" show-word-limit
                      placeholder="请输入备注内容" v-model="params.memo">
            </el-input>
          </el-form-item>
        </el-form>
      </div>
      <div style="margin-bottom: 10px">
        <el-button icon="el-icon-plus" type="primary" @click="addAcounts">添加</el-button>
        <el-button icon="el-icon-delete" type="danger" @click="deletAcounts">删除</el-button>
      </div>
      <el-table :row-key="getRowKey" ref="multipleSelections" border :data="params.itemsList"
                :row-style="{height: '61px'}" style="width: 100%" @selection-change="handleChanges"
                :header-cell-style="{'text-align': 'center'}" :cell-style="{'text-align': 'center'}">
        <el-table-column type="selection" width="50" :reserve-selection="true"></el-table-column>
        <el-table-column prop="item" label="考核项内容">
          <template slot-scope="scope">
            <el-input clearable v-model="scope.row.item" placeholder="请输入考核项内容">
            </el-input>
          </template>
        </el-table-column>
        <el-table-column prop="itemVal" label="考核项权重值">
          <template slot-scope="scope">
            <el-input clearable
                      oninput="value=value.replace(/^0[0-9]|^[2-9]|^1[0-9]|^1\.|[^\d.]/g,'').replace(/^(\-)*(\d+)\.(\d\d).*$/, '$1$2.$3')"
                      v-model="scope.row.itemVal" placeholder="请输入1以内的2位小数）">
            </el-input>
          </template>
        </el-table-column>
        <el-table-column prop="memo" label="备注">
          <template slot-scope="scope">
            <el-input clearable v-model="scope.row.memo" placeholder="请输入备注">
            </el-input>
          </template>
        </el-table-column>
        <el-table-column prop="itemSn" width="120" label="排序号">
          <template slot-scope="scope">
            <el-input type="number" min="1" @input="insort(scope.row, scope.$index)"
                      v-model="scope.row.itemSn"></el-input>
          </template>
        </el-table-column>
      </el-table>

      <span slot="footer" class="dialog-footer">
				<el-button type="primary" @click="goInfo">保 存</el-button>
				<el-button @click="handleClose">取 消</el-button>
			</span>
    </el-dialog>
  </div>
</template>
<script>
import operationCheck from '@/api/device/operationCheck.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'CheckItemDialog',
  components: {},
  data() {
    return {
      visible: false,
      title: '新增',
      activeCollapse1: '1',
      tableData: [],
      counts: 0,
      multipleSelections: [],
      params: {
        itemsList: [],
        assessTitle: '', //
        memo: '', // 备注
        assessType: '', // 考核方式（1：单位考核，2：合同考核）
        publishStatus: '0', // 发布状态
        id: null
      },
      itemsList: [],
      assessTypeList: [], //考核方式字段列表
      itemsData: [],
      fbztList: [],
      rules: {
        item: [{
          required: true,
          message: '请输入考核内容',
          trigger: 'blur'
        }],
        assessType: [{
          required: true,
          message: '请选择考核方式',
          trigger: 'blur'
        }]
      }
    }
  },
  created() {
    this.assessTypeList = dictUtils.getDictItemsFromCache('jxkh-khfs')
    this.fbztList = dictUtils.getDictItemsFromCache('fbzt')
  },
  methods: {
    add() {
      this.handleClose()
      this.visible = true
      this.params.assessType = this.assessTypeList[0].value
      this.title = '新增'
    },
    edit(row) {
      console.log(row)
      if (row.publishStatus == '0') {
        this.visible = true
      } else {
        this.visible = false
        this.$message.warning('该条考核已发布')
      }
      this.title = '修改'
      operationCheck.getItemById(row.id, (res) => {
        this.params = res
        this.params.assessYear = res.assessYear + ''
      })
    },
    insort(val, index) {
      let arr = JSON.parse(JSON.stringify(this.params.itemsList))
      arr.splice(index, 1)
      arr.forEach((e) => {
        if (val.itemSn == e.itemSn) {
          this.$message.warning('存在相同排序号')
        }
      })
    },
    addAcounts() {
      let count = this.params.itemsList.length + 1
      this.params.itemsList.push({
        itemId: '',
        endVal: null,
        startVal: null,
        val: null,
        itemSn: count
      })
    },
    deletAcounts() {
      this.params.itemsList.forEach((item, index) => {
        this.multipleSelections.forEach((ii) => {
          if (item.itemSn == ii.itemSn) {
            this.params.itemsList.splice(index, 1)
          }
        })
      })
      this.$refs.multipleSelections.clearSelection()

      // if (this.multipleSelections && this.multipleSelections.length) {
      // 	this.multipleSelections.forEach(item => {
      // 		this.params.itemsList.forEach((data, i) => {
      // 			if (item == data) {
      // 				operationCheck.remove(data.id, res => {
      // 					if (res.state) {
      // 						this.params.itemsList.splice(i, 1)
      // 						this.$refs.multipleSelections.clearSelection()
      // 					}
      // 				})
      // 			}
      // 		})
      // 	})
      // }
    },
    handleChanges(val) {
      this.multipleSelections = val
    },
    handleClose() {
      this.params = {
        itemsList: [{
          itemId: '',
          endVal: null,
          startVal: null,
          val: null,
          itemSn: 1
        }],
        assessTitle: '', //
        memo: '', // 备注
        assessType: '', // 考核方式（1：单位考核，2：合同考核）
        publishStatus: '0', // 发布状态
        id: null
      }
      this.activeCollapse1 = '1'
      this.visible = false
    },
    goInfo(e) {
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          if (this.title === '新增') {
            var isNull = false
            this.params.itemsList.forEach((item) => {
              if (item.item && item.itemVal) {
                isNull = true
              } else {
                isNull = false
              }
            })
            if (isNull) {
              operationCheck.addItems(this.params, (response) => {
                console.log(this.params, '新增')
                if (response.state) {
                  this.$notify({
                    type: 'success',
                    message: '保存成功',
                    duration: 2000
                  })
                  this.handleClose()
                  this.$parent.loadData(1)
                } else {
                }
              })
            } else {
              this.$message({
                showClose: true,
                message: '请完善考核项内容和权重值',
                type: 'warning'
              })
            }
          }
          if (this.title === '修改') {
            operationCheck.updateItems(this.params, (response) => {
              console.log(this.params, '修改')
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '修改成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.loadData(1)
              } else {
              }
            })
          }
        } else {
          return false
        }
      })
    },
    //指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    }
  }
}
</script>
<style lang="scss" scoped>
.el-divider--horizontal {
  margin: 24px 0 5px 0;
  height: 7px !important;
  background: #88b4dd !important;

  .el-divider__text {
    font-size: 16px !important;
  }
}

::v-deep .bbsl-scroll-pane .bbsl-scroll-form {
  width: calc(100% - 1.04167vw);
  height: auto;
  overflow-y: auto;
  padding: 0 0.52083vw;
}
</style>
